@@ -3,6 +3,7 @@ Defines command line services to install, setup and run apps.
 '''
 import io
 import os
+import re
 import sys
 import time
 import yaml
@@ -197,32 +198,42 @@ else:
         raise exc_info[1]
 
 
-def safe_rmtree(target, retries=100, delay=0.05):
+def _try_remove(target, retries=100, delay=0.05, func=shutil.rmtree, **kwargs):
+    for count in range(retries):
+        try:
+            func(target, **kwargs)
+        except TryAgainError:
+            pass
+        # If permission is denied, e.g. antivirus, file is open, etc, keep trying with delay
+        except OSError:
+            app_log.warning('    Trying again to delete', target)
+            time.sleep(delay)
+        else:
+            break
+
+
+def safe_rmtree(target, retries=100, delay=0.05, gramexdata=True):
     '''
-    A replacement for shutil.rmtree that removes directories within $GRAMEXDATA.
+    A replacement for shutil.rmtree and os.remove that removes directories,
+    optionally within $GRAMEXDATA.
     It tries to remove the target multiple times, recovering from errors.
     '''
     if not os.path.exists(target):
         return True
     # TODO: check case insensitive in Windows, but case sensitive on other OS
-    elif target.lower().startswith(variables['GRAMEXDATA'].lower()):
-        # Try multiple times to recover from errors, since we have no way of
-        # auto-resuming rmtree: https://bugs.python.org/issue8523
-        for count in range(retries):
-            try:
-                shutil.rmtree(target, onerror=_ensure_remove)
-            except TryAgainError:
-                pass
-            # If permission is denied, e.g. antivirus, file is open, etc, keep trying with delay
-            except OSError:
-                app_log.warning('    Trying again to delete', target)
-                time.sleep(delay)
-            else:
-                break
-        return True
+    func, kwargs = (shutil.rmtree, {'onerror': _ensure_remove}) if \
+        os.path.isdir(target) else (os.remove, {})
+    if gramexdata:
+        if target.lower().startswith(variables['GRAMEXDATA'].lower()):
+            # Try multiple times to recover from errors, since we have no way of
+            # auto-resuming rmtree: https://bugs.python.org/issue8523
+            _try_remove(target, retries, delay, func, **kwargs)
+            return True
+        else:
+            app_log.warning('Not removing directory %s (outside $GRAMEXDATA)', target)
+            return False
     else:
-        app_log.warning('Not removing directory %s (outside $GRAMEXDATA)', target)
-        return False
+        _try_remove(target, retries, delay, func, **kwargs)
 
 
 def zip_prefix_filter(members, prefix):
@@ -316,7 +327,7 @@ def run_command(config):
     if not safe_rmtree(config.target):
         app_log.error('Cannot delete target %s. Aborting installation', config.target)
         return
-    proc = Popen(appcmd, bufsize=-1, stdout=sys.stdout, stderr=sys.stderr, **kwargs)    # nosec
+    proc = Popen(appcmd, bufsize=-1, **kwargs)      # nosec
     proc.communicate()
     return proc.returncode
 
@@ -580,11 +591,10 @@ def _check_output(cmd, default=b'', **kwargs):
 
 
 def _run_console(cmd, **kwargs):
-    '''Run cmd and pipe output to console (sys.stdout / sys.stderr)'''
+    '''Run cmd and pipe output to console. Log and raise error if cmd is not found'''
     cmd = shlex.split(cmd)
     try:
-        proc = Popen(cmd, bufsize=-1, stdout=sys.stdout, stderr=sys.stderr,
-                     universal_newlines=True, **kwargs)
+        proc = Popen(cmd, bufsize=-1, universal_newlines=True, **kwargs)
     except OSError:
         app_log.error('Cannot find command: %s', cmd[0])
         raise
@@ -611,11 +621,10 @@ def _copy(source, target, template_data=None):
         app_log.info('Copy file %s', source)
         with io.open(source, 'rb') as handle:
             result = handle.read()
-            from mimetypes import guess_type
-            filetype = guess_type(source)[0]
-            basetype = 'text' if filetype is None else filetype.split('/')[0]
             if template_data is not None:
-                if basetype in {'text'} or filetype in {'application/javascript'}:
+                from mimetypes import guess_type
+                filetype = guess_type(source)[0] or 'text/unknown'
+                if re.match('text/.*|application/(json|javascript)', filetype):
                     result = Template(result).generate(**template_data)
         with io.open(target, 'wb') as handle:
             handle.write(result)
