@@ -79,13 +79,13 @@ class Classifier(object):
             else:
                 clf.fit(self.scaler.transform(x), y)
             self.model = clf
-
         # Extend the model
         else:
             x, y = data[self.input], data[self.output]
             classes = set(self.model.classes_)
             classes |= set(y)
             self.model.partial_fit(self.scaler.transform(x), y)
+        self.trained = True
 
     def predict(self, data):
         '''
@@ -127,7 +127,7 @@ def _conda_r_home():
 
 
 def r(code=None, path=None, rel=True, conda=True, convert=True,
-      repo='https://cran.microsoft.com/', **kwargs):
+      repo='https://cran.r-project.org/', **kwargs):
     '''
     Runs the R script and returns the result.
 
@@ -278,7 +278,8 @@ def _google_translate(q, source, target, key):
     return {
         'q': q,
         't': [t['translatedText'] for t in response['data']['translations']],
-        'source': [t['detectedSourceLanguage'] for t in response['data']['translations']],
+        'source': [t.get('detectedSourceLanguage', params.get('source', None))
+                   for t in response['data']['translations']],
         'target': [target] * len(q),
     }
 
@@ -310,7 +311,6 @@ def translate(*q, **kwargs):
 
     :arg str q: one or more strings to translate
     :arg str source: 2-letter source language (e.g. en, fr, es, hi, cn, etc).
-        If empty or None, auto-detects source
     :arg str target: 2-letter target language (e.g. en, fr, es, hi, cn, etc).
     :arg str key: Google Translate API key
     :arg dict cache: kwargs for :py:func:`gramex.data.filter`. Has keys such as
