@@ -412,6 +412,22 @@ class TestPPTGen(TestCase):
             eq_(shape.height, pptx.util.Inches(3))
             self.assertAlmostEqual(shape.width / shape.height, aspect, places=5)
 
+    def test_image_clone_copy(self, slides=7):
+        repeat = (0, 1, 2)
+        prs = pptgen(source=self.input, rules=[
+            {'copy-slide': repeat, 'slide-number': slides, 'Group 1': {'Picture': {
+                'clone-shape': repeat,
+                'image': self.image,
+            }}}])
+        for index in repeat:
+            slide = prs.slides[slides + index - 1]
+            group = [shape for shape in slide.shapes if shape.name == 'Group 1'][0]
+            pics = [shape for shape in group.shapes if shape.name == 'Picture']
+            eq_(len(pics), len(repeat))
+            for pic in pics[1:]:
+                pic.width == pics[0].width
+                pic.height == pics[0].height
+
     def test_fill_stroke(self, slides=3):
         colors = (
             ('red', {'rgb': (255, 0, 0)}),
@@ -961,15 +977,17 @@ class TestPPTGen(TestCase):
             'Beta': [4, 5, 6],
             'Gamma': [7, 9, ''],
         }, index=['X', 'Y', 'Z'])
-        charts = ['Column Chart', 'Line Chart', 'Bar Chart']
+        charts_2d = ['Column Chart', 'Line Chart', 'Bar Chart']
+        charts_1d = ['Pie Chart', 'Donut Chart']
         prs = pptgen(source=self.input, target=self.output, only=slides, rules=[
-            {'Pie Chart': {'chart-data': data[['Alpha']]}},
-            *({chart: {'chart-data': data}} for chart in charts)
+            *({chart: {'chart-data': data[['Alpha']]}} for chart in charts_1d),
+            *({chart: {'chart-data': data}} for chart in charts_2d)
         ])
         shapes = prs.slides[0].shapes
-        for chart in charts:
+        for chart in charts_2d:
             afe(self.chart_data(self.get_shape(shapes, chart)), data)
-        afe(self.chart_data(self.get_shape(shapes, 'Pie Chart')), data[['Alpha']])
+        for chart in charts_1d:
+            afe(self.chart_data(self.get_shape(shapes, chart)), data[['Alpha']])
 
     def test_commandline(self):
         # "slidesense" prints usage
